----- 
title:       Demos pages
sub_title:   Good places to start with CBR
description: This page contains multiple demos to that show in action the capabilities of the CBR.             
-----

 - [personas](docs/demos/personas/index)
 - [tools](docs/demos/tools/index)
 - [use-cases](docs/demos/use-cases/index)
